@@ -2,11 +2,11 @@
 import datetime
 
 # Info
-__version__ = '0.0.18'
+__version__ = '0.0.28'
 
 
 # Maintainer info
-__author__ = """NeuroKit development team"""
+__author__ = 'The NeuroKit development team'
 __email__ = 'dom.makowski@gmail.com'
 
 
@@ -16,7 +16,7 @@ __email__ = 'dom.makowski@gmail.com'
 __cite__ = """
 You can cite NeuroKit2 as follows:
 
-- Makowski, D., Pham, T., Lau, Z. J., Brammer, J. C., Pham, H., Lesspinasse, F.,
+- Makowski, D., Pham, T., Lau, Z. J., Brammer, J. C., Lesspinasse, F., Pham, H.,
   Schölzel, C., & S H Chen, A. (2020). NeuroKit2: A Python Toolbox for Neurophysiological
   Signal Processing. Retrieved """ + datetime.date.today().strftime("%B %d, %Y") + """, from https://github.com/neuropsychology/NeuroKit
 
@@ -26,7 +26,7 @@ Full bibtex reference:
 @misc{neurokit2,
   doi = {10.5281/ZENODO.3597887},
   url = {https://github.com/neuropsychology/NeuroKit},
-  author = {Makowski, Dominique and Pham, Tam and Lau, Zen J. and Brammer, Jan C. and Pham, Hung and Lesspinasse, Fran\c{c}ois and Schölzel, Christopher and S H Chen, Annabel},
+  author = {Makowski, Dominique and Pham, Tam and Lau, Zen J. and Brammer, Jan C. and Lesspinasse, Fran\c{c}ois and Pham, Hung and Schölzel, Christopher and S H Chen, Annabel},
   title = {NeuroKit2: A Python Toolbox for Neurophysiological Signal Processing},
   publisher = {Zenodo},
   month={Mar},
