@@ -6,7 +6,7 @@ import numpy as np
 
 
 def entropy_shannon(signal):
-    """Compute the Shannon entropy (SE).
+    """Compute the Shannon entropy (SE)
 
     Entropy is a measure of unpredictability of the state, or equivalently, of its average information content. Shannon entropy (SE) is one of the first and most basic measure of entropy and a foundational concept of information theory. Shannon’s entropy quantifies the amount of information in a variable.
 
