@@ -6,6 +6,7 @@ from .ecg_findpeaks import ecg_findpeaks
 from .ecg_fixpeaks import ecg_fixpeaks
 from .ecg_peaks import ecg_peaks
 from .ecg_rate import ecg_rate
+from .ecg_segment import ecg_segment
 from .ecg_process import ecg_process
 from .ecg_plot import ecg_plot
 from .ecg_delineate import ecg_delineate
@@ -14,5 +15,6 @@ from .ecg_rsp import ecg_rsp
 from .ecg_hrv import ecg_hrv
 from .ecg_phase import ecg_phase
 from .ecg_rsa import ecg_rsa
+from .ecg_quality import ecg_quality
 from .ecg_intervalrelated import ecg_intervalrelated
 from .ecg_analyze import ecg_analyze
