@@ -13,12 +13,14 @@ from ..signal import (signal_zerocrossings,
                       signal_findpeaks,
                       signal_formatpeaks)
 from .ecg_peaks import ecg_peaks
+from .ecg_segment import ecg_segment
 from ..epochs import epochs_create
 from ..epochs import epochs_to_df
 from ..events import events_plot
+from ..stats import standardize
 
 
-def ecg_delineate(ecg_cleaned, rpeaks, sampling_rate=1000, method="peak", show=False, show_type='peaks'):
+def ecg_delineate(ecg_cleaned, rpeaks=None, sampling_rate=1000, method="peak", show=False, show_type='peaks', check=False):
     """Delineate QRS complex.
     Function to delineate the QRS complex.
 
@@ -26,8 +28,8 @@ def ecg_delineate(ecg_cleaned, rpeaks, sampling_rate=1000, method="peak", show=F
 
     Parameters
     ----------
-    ecg : list, array or Series
-        The raw ECG signal.
+    ecg_cleaned : list, array or Series
+        The cleaned ECG channel as returned by `ecg_clean()`.
     rpeaks : list, array or Series
         The samples at which R-peaks occur. Accessible with the key "ECG_R_Peaks" in the info dictionary returned by `ecg_findpeaks()`.
     sampling_rate : int
@@ -81,11 +83,29 @@ def ecg_delineate(ecg_cleaned, rpeaks, sampling_rate=1000, method="peak", show=F
     - Martínez, J. P., Almeida, R., Olmos, S., Rocha, A. P., & Laguna, P. (2004). A wavelet-based ECG delineator: evaluation on standard databases. IEEE Transactions on biomedical engineering, 51(4), 570-581.
 
     """
-    # Sanitize inputs
+    # Sanitize input for ecg_cleaned
+    if isinstance(ecg_cleaned, pd.DataFrame):
+        cols = [col for col in ecg_cleaned.columns if 'ECG_Clean' in col]
+        if len(cols) == 0:
+            raise ValueError("NeuroKit error: ecg_delineate(): Wrong input,"
+                             "we couldn't extract cleaned signal.")
+        else:
+            ecg_cleaned = ecg_cleaned[cols[0]].values
+    elif isinstance(ecg_cleaned, dict):
+        for i in ecg_cleaned:
+            cols = [col for col in ecg_cleaned[i].columns if 'ECG_Clean' in col]
+            if len(cols) == 0:
+                raise ValueError("NeuroKit error: ecg_delineate(): Wrong input,"
+                                 "we couldn't extract cleaned signal.")
+            else:
+                signals = epochs_to_df(ecg_cleaned)
+                ecg_cleaned = signals[cols[0]].values
+
+    # Sanitize input for rpeaks
     if rpeaks is None:
         _, rpeaks = ecg_peaks(ecg_cleaned, sampling_rate=sampling_rate)
+        rpeaks = rpeaks["ECG_R_Peaks"]
 
-    # Try retrieving right column
     if isinstance(rpeaks, dict):
         rpeaks = rpeaks["ECG_R_Peaks"]
 
@@ -103,17 +123,24 @@ def ecg_delineate(ecg_cleaned, rpeaks, sampling_rate=1000, method="peak", show=F
                                    rpeaks,
                                    sampling_rate=sampling_rate)
 
-    # Remove NaN in Peaks, Onsets, and Offsets
-    for feature in waves.keys():
-        waves[feature] = [x for x in waves[feature] if ~np.isnan(x)]
+    else:
+        raise ValueError("NeuroKit error: ecg_delineate(): 'method' should be "
+                         "one of 'peak', 'cwt' or 'dwt'.")
 
-    instant_peaks = signal_formatpeaks(waves,
+    # Remove NaN in Peaks, Onsets, and Offsets
+    waves_noNA = waves.copy()
+    for feature in waves_noNA.keys():
+        waves_noNA[feature] = [int(x) for x in waves_noNA[feature] if ~np.isnan(x)]
+
+    instant_peaks = signal_formatpeaks(waves_noNA,
                                        desired_length=len(ecg_cleaned))
     signals = instant_peaks
 
     if show is True:
         _ecg_delineate_plot(ecg_cleaned, rpeaks=rpeaks, signals=signals, signal_features_type=show_type, sampling_rate=sampling_rate)
 
+    if check is True:
+        waves = _ecg_delineate_check(waves, rpeaks)
 
     return signals, waves
 
@@ -126,7 +153,7 @@ def ecg_delineate(ecg_cleaned, rpeaks, sampling_rate=1000, method="peak", show=F
 def _dwt_resample_points(peaks, sampling_rate, desired_sampling_rate):
     """Resample given points to a different sampling rate."""
     peaks_resample = (np.array(peaks) * desired_sampling_rate / sampling_rate)
-    peaks_resample = peaks_resample[~np.isnan(peaks_resample)].astype(int)
+    peaks_resample = [np.nan if np.isnan(x) else int(x) for x in peaks_resample.tolist()]
     return peaks_resample
 
 
@@ -152,8 +179,8 @@ def _dwt_ecg_delinator(ecg, rpeaks, sampling_rate, analysis_sampling_rate=2000):
     # plt.legend()
     # plt.grid(True)
     # plt.show()
-
     rpeaks_resampled = _dwt_resample_points(rpeaks, sampling_rate, analysis_sampling_rate)
+
     tpeaks, ppeaks = _dwt_delinate_tp_peaks(
         ecg, rpeaks_resampled, dwtmatr, sampling_rate=analysis_sampling_rate, debug=False)
     qrs_onsets, qrs_offsets = _dwt_delinate_qrs_bounds(
@@ -167,12 +194,12 @@ def _dwt_ecg_delinator(ecg, rpeaks, sampling_rate, analysis_sampling_rate=2000):
 
     return dict(
         ECG_T_Peaks=_dwt_resample_points(tpeaks, analysis_sampling_rate, desired_sampling_rate=sampling_rate),
-        ECG_T_Onsets=_dwt_resample_points(tonsets, analysis_sampling_rate, desired_sampling_rate=sampling_rate)[:-1],
+        ECG_T_Onsets=_dwt_resample_points(tonsets, analysis_sampling_rate, desired_sampling_rate=sampling_rate),
         ECG_T_Offsets=_dwt_resample_points(toffsets, analysis_sampling_rate, desired_sampling_rate=sampling_rate),
-        ECG_P_Peaks=_dwt_resample_points(ppeaks, analysis_sampling_rate, desired_sampling_rate=sampling_rate)[1:],
-        ECG_P_Onsets=_dwt_resample_points(ponsets, analysis_sampling_rate, desired_sampling_rate=sampling_rate)[1:],
+        ECG_P_Peaks=_dwt_resample_points(ppeaks, analysis_sampling_rate, desired_sampling_rate=sampling_rate),
+        ECG_P_Onsets=_dwt_resample_points(ponsets, analysis_sampling_rate, desired_sampling_rate=sampling_rate),
         ECG_P_Offsets=_dwt_resample_points(poffsets, analysis_sampling_rate, desired_sampling_rate=sampling_rate),
-        ECG_R_Onsets=_dwt_resample_points(qrs_onsets, analysis_sampling_rate, desired_sampling_rate=sampling_rate)[1:],
+        ECG_R_Onsets=_dwt_resample_points(qrs_onsets, analysis_sampling_rate, desired_sampling_rate=sampling_rate),
         ECG_R_Offsets=_dwt_resample_points(qrs_offsets, analysis_sampling_rate, desired_sampling_rate=sampling_rate),
     )
 
@@ -194,7 +221,10 @@ def _dwt_delinate_tp_peaks(ecg, rpeaks, dwtmatr, sampling_rate=250, debug=False,
     degree_add = _dwt_compensate_degree(sampling_rate)
 
     tpeaks = []
-    for i in range(len(rpeaks)-1):
+    for i in range(len(rpeaks)):
+        if np.isnan(rpeaks[i]):
+            tpeaks.append(np.nan)
+            continue
         # search for T peaks from R peaks
         srch_idx_start = rpeaks[i] + srch_bndry
         srch_idx_end = rpeaks[i] + 2 * int(rt_duration * sampling_rate)
@@ -232,7 +262,10 @@ def _dwt_delinate_tp_peaks(ecg, rpeaks, dwtmatr, sampling_rate=250, debug=False,
         tpeaks.append(candidate_peaks[np.argmax(candidate_peaks_scores)] + srch_idx_start)
 
     ppeaks = []
-    for i in range(len(rpeaks)-1):
+    for i in range(len(rpeaks)):
+        if np.isnan(rpeaks[i]):
+            ppeaks.append(np.nan)
+            continue
 
         # search for P peaks from Rpeaks
         srch_idx_start = rpeaks[i] - 2 * int(p2r_duration * sampling_rate)
@@ -284,11 +317,16 @@ def _dwt_delinate_tp_onsets_offsets(ecg, peaks, dwtmatr, sampling_rate=250, debu
     onsets = []
     offsets = []
     for i in range(len(peaks)):
+        if np.isnan(peaks[i]):
+            onsets.append(np.nan)
+            offsets.append(np.nan)
+            continue
         # look for onsets
         srch_idx_start = peaks[i] - int(duration * sampling_rate)
         srch_idx_end = peaks[i]
         if srch_idx_start is np.nan or srch_idx_end is np.nan:
             onsets.append(np.nan)
+            offsets.append(np.nan)
             continue
         dwt_local = dwtmatr[degree_onset + degree, srch_idx_start: srch_idx_end]
         onset_slope_peaks, onset_slope_data = scipy.signal.find_peaks(dwt_local)
@@ -308,7 +346,7 @@ def _dwt_delinate_tp_onsets_offsets(ecg, peaks, dwtmatr, sampling_rate=250, debu
         srch_idx_start = peaks[i]
         srch_idx_end = peaks[i] + int(duration_offset * sampling_rate)
         if srch_idx_start is np.nan or srch_idx_end is np.nan:
-            onsets.append(np.nan)
+            offsets.append(np.nan)
             continue
         dwt_local = dwtmatr[degree_offset + degree, srch_idx_start: srch_idx_end]
         offset_slope_peaks, offset_slope_data = scipy.signal.find_peaks(-dwt_local)
@@ -324,13 +362,13 @@ def _dwt_delinate_tp_onsets_offsets(ecg, peaks, dwtmatr, sampling_rate=250, debu
         # plt.plot(ecg[srch_idx_start: srch_idx_end], '--', label='ecg')
         # plt.show()
 
-    return np.array(onsets), np.array(offsets)
+    return onsets, offsets
 
 
 def _dwt_delinate_qrs_bounds(ecg, rpeaks, dwtmatr, ppeaks, tpeaks, sampling_rate=250, debug=False):
     degree = int(np.log2(sampling_rate / 250))
     onsets = []
-    for i in range(len(rpeaks) - 1):
+    for i in range(len(rpeaks)):
         # look for onsets
         srch_idx_start = ppeaks[i]
         srch_idx_end = rpeaks[i]
@@ -348,8 +386,9 @@ def _dwt_delinate_qrs_bounds(ecg, rpeaks, dwtmatr, ppeaks, tpeaks, sampling_rate
         # plt.plot(ecg[srch_idx_start: srch_idx_end], '--', label='ecg')
         # plt.legend()
         # plt.show()
+
     offsets = []
-    for i in range(len(rpeaks) - 1):
+    for i in range(len(rpeaks)):
         # look for offsets
         srch_idx_start = rpeaks[i]
         srch_idx_end = tpeaks[i]
@@ -369,7 +408,7 @@ def _dwt_delinate_qrs_bounds(ecg, rpeaks, dwtmatr, ppeaks, tpeaks, sampling_rate
 
         offsets.append(candidate_offsets[0] + srch_idx_start)
 
-    return np.array(onsets), np.array(offsets)
+    return onsets, offsets
 
 
 
@@ -637,18 +676,12 @@ def _find_tppeaks(ecg, keep_tp, sampling_rate=1000):
     return tppeaks
 
 # =============================================================================
-#                              DERIVATIVE METHOD
+#                              PEAK METHOD
 # =============================================================================
 def _ecg_delineator_peak(ecg, rpeaks=None, sampling_rate=1000):
 
     # Initialize
-    epochs_start, epochs_end = _ecg_delineate_beatwindow(rpeaks=rpeaks,
-                                                         sampling_rate=sampling_rate)
-    heartbeats = epochs_create(ecg,
-                               rpeaks,
-                               sampling_rate=sampling_rate,
-                               epochs_start=epochs_start,
-                               epochs_end=epochs_end)
+    heartbeats = ecg_segment(ecg, rpeaks, sampling_rate)
 
     Q_list = []
     P_list = []
@@ -761,8 +794,6 @@ def _ecg_delineator_peak_T(rpeak, heartbeat, R, S):
 
 
 
-
-
 def _ecg_delineator_peak_P_onset(rpeak, heartbeat, R, P):
     if P is None:
         return np.nan
@@ -772,6 +803,10 @@ def _ecg_delineator_peak_P_onset(rpeak, heartbeat, R, P):
         signal = signal_smooth(segment["Signal"].values, size=R/10)
     except TypeError:
         signal = segment["Signal"]
+
+    if len(signal) < 2:
+        return np.nan
+
     signal = np.gradient(np.gradient(signal))
     P_onset = np.argmax(signal)
 
@@ -789,6 +824,10 @@ def _ecg_delineator_peak_T_offset(rpeak, heartbeat, R, T):
         signal = signal_smooth(segment["Signal"].values, size=R/10)
     except TypeError:
         signal = segment["Signal"]
+
+    if len(signal) < 2:
+        return np.nan
+
     signal = np.gradient(np.gradient(signal))
     T_offset = np.argmax(signal)
 
@@ -798,23 +837,6 @@ def _ecg_delineator_peak_T_offset(rpeak, heartbeat, R, T):
 # =============================================================================
 # Internals
 # =============================================================================
-def _ecg_delineate_beatwindow(heart_rate=None, rpeaks=None, sampling_rate=1000):
-
-    # Extract heart rate
-    if heart_rate is not None:
-        heart_rate = np.mean(heart_rate)
-    if rpeaks is not None:
-        heart_rate = np.mean(np.diff(rpeaks) / sampling_rate * 60)
-
-    # Modulator
-    m = heart_rate/80
-
-    # Window
-    epochs_start = -0.35/m
-    epochs_end = 0.5/m
-
-    return epochs_start, epochs_end
-
 
 def _ecg_delineate_plot(ecg_signal, rpeaks=None, signals=None, signal_features_type='all', sampling_rate=1000):
 
@@ -826,7 +848,7 @@ def _ecg_delineate_plot(ecg_signal, rpeaks=None, signals=None, signal_features_t
     >>> import pandas as pd
     >>> import matplotlib.pyplot as plt
 
-    >>> ecg_signal = np.array(pd.read_csv("https://raw.githubusercontent.com/neuropsychology/NeuroKit/dev/data/example_ecg_1000hz.csv"))[:, 1]
+    >>> ecg_signal = np.array(pd.read_csv("https://raw.githubusercontent.com/neuropsychology/NeuroKit/dev/data/ecg_1000hz.csv"))[:, 1]
 
     >>> # Extract R-peaks locations
     >>> _, rpeaks = nk.ecg_peaks(ecg_signal, sampling_rate=1000)
@@ -896,6 +918,7 @@ def _ecg_delineate_plot(ecg_signal, rpeaks=None, signals=None, signal_features_t
     features = pd.concat(dfs, axis=1)
 
     fig, ax = plt.subplots()
+    data.Label = data.Label.astype(int)
     for label in data.Label.unique():
         epoch_data = data[data.Label == label]
         ax.plot(epoch_data.Time, epoch_data.Signal, color='grey', alpha=0.2,  label='_nolegend_')
@@ -905,3 +928,43 @@ def _ecg_delineate_plot(ecg_signal, rpeaks=None, signals=None, signal_features_t
                    label=feature_type, alpha=0.5, s=200)
         ax.legend()
     return fig
+
+
+
+def _ecg_delineate_check(waves, rpeaks):
+    """
+    This function replaces the delineated features with np.nan if its
+    standardized distance from R-peaks is more than 3
+    """
+    df = pd.DataFrame.from_dict(waves)
+    features_columns = df.columns
+
+    df = pd.concat([df, pd.DataFrame({'ECG_R_Peaks': rpeaks})], axis=1)
+
+    # loop through all columns to calculate the z distance
+    for column in features_columns:
+        df = _calculate_abs_z(df, features_columns)
+
+    distance_columns = [col for col in df.columns if 'Dist' in col]
+
+    # Replace with nan if distance > 3
+    for col in features_columns:
+        for i in range(len(df)):
+            if df['Dist_R_' + col][i] > 3:
+                df[col][i] = np.nan
+
+    # Return df without distance columns
+    df = df[features_columns]
+    waves = df.to_dict('list')
+    return waves
+
+
+
+def _calculate_abs_z(df, columns):
+    """
+    This function helps to calculate the absolute standardized distance
+    between R-peaks and other delineated waves features by `ecg_delineate()`
+    """
+    for column in columns:
+        df['Dist_R_' + column] = np.abs(standardize(df[column].sub(df['ECG_R_Peaks'], axis=0)))
+    return df
