@@ -7,3 +7,5 @@ from .emg_process import emg_process
 from .emg_plot import emg_plot
 from .emg_activation import emg_activation
 from .emg_eventrelated import emg_eventrelated
+from .emg_intervalrelated import emg_intervalrelated
+from .emg_analyze import emg_analyze
