@@ -92,6 +92,13 @@ def emg_eventrelated(epochs):
 
     emg_df = pd.DataFrame.from_dict(emg_df, orient="index")  # Convert to a dataframe
 
+    # Move columns to front
+    colnames = emg_df.columns.values
+    if len([i for i in colnames if "Condition" in i]) == 1:
+        emg_df = emg_df[['Condition'] + [col for col in emg_df.columns if col != 'Condition']]
+    if len([i for i in colnames if "Label" in i]) == 1:
+        emg_df = emg_df[['Label'] + [col for col in emg_df.columns if col != 'Label']]
+
     return emg_df
 
 
