@@ -6,7 +6,7 @@ from ..signal import signal_resample
 
 
 def emg_simulate(duration=10, length=None, sampling_rate=1000, noise=0.01,
-                 n_bursts=1, duration_bursts=1.0, random_state=42):
+                 burst_number=1, burst_duration=1.0, random_state=42):
     """Simulate an EMG signal
 
     Generate an artificial (synthetic) EMG signal of a given duration and sampling rate.
@@ -20,9 +20,9 @@ def emg_simulate(duration=10, length=None, sampling_rate=1000, noise=0.01,
         length of the signal (in samples).
     noise : float
         Noise level (gaussian noise).
-    n_bursts : int
+    burst_number : int
         Desired number of bursts of activity (active muscle periods).
-    duration_bursts : float or list
+    burst_duration : float or list
         Duration of the bursts. Can be a float (each burst will have the same
         duration) or a list of durations for each bursts.
     random_state : int
@@ -38,7 +38,7 @@ def emg_simulate(duration=10, length=None, sampling_rate=1000, noise=0.01,
     >>> import neurokit as nk
     >>> import pandas as pd
     >>>
-    >>> emg = nk.emg_simulate(duration=10, n_bursts=3)
+    >>> emg = nk.emg_simulate(duration=10, burst_number=3)
     >>> nk.signal_plot(emg)
 
     See Also
@@ -58,25 +58,25 @@ def emg_simulate(duration=10, length=None, sampling_rate=1000, noise=0.01,
         length = duration * sampling_rate
 
     # Sanity checks
-    if isinstance(duration_bursts, int) or isinstance(duration_bursts, float):
-        duration_bursts = np.repeat(duration_bursts, n_bursts)
+    if isinstance(burst_duration, int) or isinstance(burst_duration, float):
+        burst_duration = np.repeat(burst_duration, burst_number)
 
-    if len(duration_bursts) > n_bursts:
-        raise ValueError("NeuroKit error: emg_simulate(): 'duration_bursts'"
-                         " cannot be longer than the value of 'n_bursts'")
+    if len(burst_duration) > burst_number:
+        raise ValueError("NeuroKit error: emg_simulate(): 'burst_duration'"
+                         " cannot be longer than the value of 'burst_number'")
 
-    total_duration_bursts = np.sum(duration_bursts)
+    total_duration_bursts = np.sum(burst_duration)
     if total_duration_bursts > duration:
         raise ValueError("NeuroKit error: emg_simulate(): The total duration"
                          " of bursts cannot exceed the total duration")
 
     # Generate bursts
     bursts = []
-    for burst in range(n_bursts):
-        bursts += [list(np.random.uniform(-1, 1, size=int(1000*duration_bursts[burst])) + 0.08)]
+    for burst in range(burst_number):
+        bursts += [list(np.random.uniform(-1, 1, size=int(1000*burst_duration[burst])) + 0.08)]
 
     # Generate quiet
-    n_quiet = n_bursts + 1  # number of quiet periods (in between bursts)
+    n_quiet = burst_number + 1  # number of quiet periods (in between bursts)
     duration_quiet = (duration - total_duration_bursts) / n_quiet  # duration of each quiet period
     quiets = []
     for quiet in range(n_quiet):
@@ -99,4 +99,4 @@ def emg_simulate(duration=10, length=None, sampling_rate=1000, noise=0.01,
                           desired_length=length,
                           desired_sampling_rate=sampling_rate)
 
-    return(emg)
+    return emg
