@@ -12,3 +12,5 @@ from .rsp_process import rsp_process
 from .rsp_plot import rsp_plot
 from .rsp_eventrelated import rsp_eventrelated
 from .rsp_rrv import rsp_rrv
+from .rsp_intervalrelated import rsp_intervalrelated
+from .rsp_analyze import rsp_analyze
