@@ -60,6 +60,15 @@ def signal_interpolate(x_values, y_values, desired_length, method="quadratic"):
     >>> plt.plot(new_x, interpolated, '-',
                  x, signal, 'o')
     """
+    # Sanity checks
+    if len(x_values) != len(y_values):
+        raise ValueError("NeuroKit error: signal_interpolate(): x_values and y_values "
+                         "must be of the same length.")
+
+    if desired_length is None or len(x_values) == desired_length:
+        return y_values
+
+
     # Create interpolation function
     interpolation_function = scipy.interpolate.interp1d(x_values,
                                                         y_values,
