@@ -157,7 +157,8 @@ def test_ecg_process():
     # Only check array dimensions and column names since functions called by
     # ecg_process have already been unit tested
     assert all(elem in ["ECG_Raw", "ECG_Clean", "ECG_R_Peaks", "ECG_Rate",
-                        "ECG_P_Peaks", "ECG_Q_Peaks", "ECG_S_Peaks",
+                        'ECG_Quality', "ECG_P_Peaks",
+                        "ECG_Q_Peaks", "ECG_S_Peaks",
                         "ECG_T_Peaks", "ECG_P_Onsets", "ECG_T_Offsets",
                         "ECG_Atrial_Phase", "ECG_Ventricular_Phase",
                         "ECG_Atrial_PhaseCompletion",
@@ -279,7 +280,7 @@ def test_ecg_eventrelated():
                       np.array(ecg_eventrelated["ECG_Rate_Max"]))
 
     assert len(ecg_eventrelated["Label"]) == 3
-    assert len(ecg_eventrelated.columns) == 13
+    assert len(ecg_eventrelated.columns) == 14
 
     assert all(elem in ["ECG_Rate_Max", "ECG_Rate_Min", "ECG_Rate_Mean",
                         "ECG_Rate_Max_Time", "ECG_Rate_Min_Time",
@@ -288,7 +289,8 @@ def test_ecg_eventrelated():
                         "ECG_Atrial_Phase",
                         "ECG_Atrial_PhaseCompletion",
                         "ECG_Ventricular_Phase",
-                        "ECG_Ventricular_PhaseCompletion", "Label"]
+                        "ECG_Ventricular_PhaseCompletion",
+                        'ECG_Quality_Mean',"Label"]
                for elem in np.array(ecg_eventrelated.columns.values, dtype=str))
 
 
@@ -326,11 +328,11 @@ def test_ecg_hrv():
     ecg_slow = nk.ecg_simulate(duration=60, sampling_rate=1000, heart_rate=70, random_state=42)
     ecg_fast = nk.ecg_simulate(duration=60, sampling_rate=1000, heart_rate=110, random_state=42)
 
-    ecg_slow, _ = nk.ecg_process(ecg_slow)
-    ecg_fast, _ = nk.ecg_process(ecg_fast)
+    ecg_slow, _ = nk.ecg_process(ecg_slow, sampling_rate=1000)
+    ecg_fast, _ = nk.ecg_process(ecg_fast, sampling_rate=1000)
 
-    ecg_slow_hrv = nk.ecg_hrv(ecg_slow)
-    ecg_fast_hrv = nk.ecg_hrv(ecg_fast)
+    ecg_slow_hrv = nk.ecg_hrv(ecg_slow, sampling_rate=1000)
+    ecg_fast_hrv = nk.ecg_hrv(ecg_fast, sampling_rate=1000)
 
     assert ecg_fast_hrv["HRV_RMSSD"][0] < ecg_slow_hrv["HRV_RMSSD"][0]
     assert ecg_fast_hrv["HRV_MeanNN"][0] < ecg_slow_hrv["HRV_MeanNN"][0]
@@ -343,12 +345,9 @@ def test_ecg_hrv():
     assert ecg_fast_hrv["HRV_pNN50"][0] == ecg_slow_hrv["HRV_pNN50"][0]
     assert ecg_fast_hrv["HRV_pNN20"][0] < ecg_slow_hrv["HRV_pNN20"][0]
     assert ecg_fast_hrv["HRV_TINN"][0] < ecg_slow_hrv["HRV_TINN"][0]
-#    assert ecg_fast_hrv["HRV_HTI"][0] > ecg_slow_hrv["HRV_HTI"][0]
-#    assert ecg_fast_hrv["HRV_ULF"][0] == ecg_slow_hrv["HRV_ULF"][0] == 0
-#    assert ecg_fast_hrv["HRV_VLF"][0] < ecg_slow_hrv["HRV_VLF"][0]
-#    assert ecg_fast_hrv["HRV_LF"][0] < ecg_slow_hrv["HRV_LF"][0]
-#    assert ecg_fast_hrv["HRV_HF"][0] < ecg_slow_hrv["HRV_HF"][0]
-#    assert ecg_fast_hrv["HRV_VHF"][0] > ecg_slow_hrv["HRV_VHF"][0]
+    assert ecg_fast_hrv["HRV_HTI"][0] > ecg_slow_hrv["HRV_HTI"][0]
+    assert ecg_fast_hrv["HRV_ULF"][0] == ecg_slow_hrv["HRV_ULF"][0] == 0
+
 
     assert all(elem in ['HRV_RMSSD', 'HRV_MeanNN', 'HRV_SDNN', 'HRV_SDSD', 'HRV_CVNN',
                         'HRV_CVSD', 'HRV_MedianNN', 'HRV_MadNN', 'HRV_MCVNN',
@@ -358,3 +357,40 @@ def test_ecg_hrv():
                         'HRV_SD1', 'HRV_SD2', 'HRV_SD2SD1', 'HRV_CSI', 'HRV_CVI',
                         'HRV_CSI_Modified', 'HRV_SampEn']
                for elem in np.array(ecg_fast_hrv.columns.values, dtype=str))
+
+    # Test frequency domain
+    ecg1 = nk.ecg_simulate(duration=60, sampling_rate=2000, heart_rate=70, random_state=42)
+    hrv1 = nk.ecg_hrv(nk.ecg_process(ecg1, sampling_rate=2000)[0], sampling_rate=2000)
+
+    ecg2 = nk.signal_resample(ecg1, sampling_rate=2000, desired_sampling_rate=500)
+    hrv2 = nk.ecg_hrv(nk.ecg_process(ecg2, sampling_rate=500)[0], sampling_rate=500)
+
+    assert np.allclose(np.mean(hrv1[["HRV_HF", "HRV_LF", "HRV_VLF"]].iloc[0] - hrv2[["HRV_HF", "HRV_LF", "HRV_VLF"]].iloc[0]), 0, atol=1)
+
+
+def test_ecg_intervalrelated():
+
+    data = nk.data("bio_resting_5min_100hz")
+    df, info = nk.ecg_process(data["ECG"], sampling_rate=100)
+    columns = ['ECG_Rate_Mean', 'HRV_RMSSD', 'HRV_MeanNN', 'HRV_SDNN', 'HRV_SDSD',
+               'HRV_CVNN', 'HRV_CVSD', 'HRV_MedianNN', 'HRV_MadNN', 'HRV_MCVNN',
+               'HRV_pNN50', 'HRV_pNN20', 'HRV_TINN', 'HRV_HTI', 'HRV_ULF',
+               'HRV_VLF', 'HRV_LF', 'HRV_HF', 'HRV_VHF', 'HRV_LFHF', 'HRV_LFn',
+               'HRV_HFn', 'HRV_LnHF', 'HRV_SD1', 'HRV_SD2', 'HRV_SD2SD1',
+               'HRV_CSI', 'HRV_CVI', 'HRV_CSI_Modified', 'HRV_SampEn']
+
+    # Test with signal dataframe
+    features_df = nk.ecg_intervalrelated(df)
+
+    assert all(elem in columns for elem
+               in np.array(features_df.columns.values, dtype=str))
+    assert features_df.shape[0] == 1  # Number of rows
+
+    # Test with dict
+    epochs = nk.epochs_create(df, events=[0, 15000],
+                              sampling_rate=100, epochs_end=150)
+    features_dict = nk.ecg_intervalrelated(epochs)
+
+    assert all(elem in columns for elem
+               in np.array(features_dict.columns.values, dtype=str))
+    assert features_dict.shape[0] == 2  # Number of rows
