@@ -90,6 +90,32 @@ def test_eda_peaks():
     onsets, peaks, amplitudes = biosppy.eda.kbk_scr(eda_phasic, sampling_rate=1000)
     assert np.allclose((info["SCR_Peaks"] - peaks).mean(), 0, atol=1)
 
+
+def test_eda_process():
+
+    eda = nk.eda_simulate(duration=30, scr_number=5,
+                          drift=0.1, noise=0, sampling_rate=250)
+    signals, info = nk.eda_process(eda, sampling_rate=250)
+
+    assert signals.shape == (7500, 11)
+    assert np.array(["EDA_Raw",
+                     "EDA_Clean",
+                     "EDA_Tonic",
+                     "EDA_Phasic",
+                     "SCR_Onsets",
+                     "SCR_Peaks",
+                     "SCR_Height",
+                     "SCR_Amplitude",
+                     "SCR_RiseTime",
+                     "SCR_Recovery",
+                     "SCR_RecoveryTime"]) in signals.columns.values
+
+    # Check equal number of markers
+    peaks = np.where(signals["SCR_Peaks"] == 1)[0]
+    onsets = np.where(signals["SCR_Onsets"] == 1)[0]
+    recovery = np.where(signals["SCR_Recovery"] == 1)[0]
+    assert peaks.shape == onsets.shape == recovery.shape == (5,)
+
 def test_eda_plot():
 
     sampling_rate = 1000
@@ -128,15 +154,37 @@ def test_eda_eventrelated():
                               epochs_start=-0.1, epochs_end=1.9)
     eda_eventrelated = nk.eda_eventrelated(epochs)
 
-    no_activation = np.where(eda_eventrelated["EDA_Activation"] == 0)[0][0]
+    no_activation = np.where(eda_eventrelated["EDA_SCR"] == 0)[0][0]
     assert int(pd.DataFrame(eda_eventrelated.values
                             [no_activation]).isna().sum()) == 4
 
     assert len(eda_eventrelated["Label"]) == 3
-    assert len(eda_eventrelated.columns) == 6
+    assert len(eda_eventrelated.columns) == 7
 
-    assert all(elem in ["EDA_Activation", "EDA_Peak_Amplitude",
-                        "EDA_Peak_Amplitude_Time",
-                        "EDA_RiseTime", "EDA_RecoveryTime",
-                        "Label"]
+    assert all(elem in ['Label', 'EDA_Peak_Amplitude', 'EDA_SCR',
+                        'SCR_Peak_Amplitude', 'SCR_Peak_Amplitude_Time',
+                        'SCR_RiseTime', 'SCR_RecoveryTime']
                for elem in np.array(eda_eventrelated.columns.values, dtype=str))
+
+
+def test_eda_intervalrelated():
+
+    data = nk.data("bio_resting_8min_100hz")
+    df, info = nk.eda_process(data["EDA"], sampling_rate=100)
+    columns = ['SCR_Peaks_N', 'SCR_Peaks_Amplitude_Mean']
+
+    # Test with signal dataframe
+    features_df = nk.eda_intervalrelated(df)
+
+    assert all(elem in columns for elem
+               in np.array(features_df.columns.values, dtype=str))
+    assert features_df.shape[0] == 1  # Number of rows
+
+    # Test with dict
+    epochs = nk.epochs_create(df, events=[0, 25300],
+                              sampling_rate=100, epochs_end=20)
+    features_dict = nk.eda_intervalrelated(epochs)
+
+    assert all(elem in columns for elem
+               in np.array(features_dict.columns.values, dtype=str))
+    assert features_dict.shape[0] == 2  # Number of rows
